@@ -1,5 +1,6 @@
 import click
 from sanic import Sanic
+
 from fpx.model import Client
 
 
@@ -12,7 +13,7 @@ def client():
 @click.pass_obj
 @click.argument("name")
 def add(app: Sanic, name: str):
-    sess = app.DbSession()
+    sess = app.ctx.db_session()
     client = Client(name)
     sess.add(client)
     sess.commit()
@@ -23,7 +24,7 @@ def add(app: Sanic, name: str):
 @click.pass_obj
 @click.argument("name")
 def drop(app: Sanic, name: str):
-    sess = app.DbSession()
+    sess = app.ctx.db_session()
     sess.query(Client).filter_by(name=name).delete()
     sess.commit()
     click.secho(f"Client removed", fg="green")
@@ -33,7 +34,7 @@ def drop(app: Sanic, name: str):
 @click.pass_obj
 @click.argument("name")
 def regenerate(app: Sanic, name: str):
-    sess = app.DbSession()
+    sess = app.ctx.db_session()
     client = sess.query(Client).filter_by(name=name).first()
     sess.delete(client)
     sess.commit()
@@ -49,7 +50,7 @@ def regenerate(app: Sanic, name: str):
 @client.command()
 @click.pass_obj
 def list(app: Sanic):
-    sess = app.DbSession()
+    sess = app.ctx.db_session()
     click.echo("Clients:")
     for client in sess.query(Client):
         click.echo(f"\t{client}")
